from pygments.style import Style
from pygments.token import (Keyword, Name, Comment, String, Error,
    Number, Operator, Generic, Whitespace, Punctuation, Text, Literal, Other)


# This will define a style called "jupyter_python"
class Jupyter_PythonStyle(Style):
    background_color = "#f8f8f8"
    default_style = ""
    styles = {
        Whitespace:                "#bbbbbb",
        Comment:                   "italic #408080",
        Comment.Preproc:           "noitalic #BC7A00",

        # Keyword:                   "bold #AA22FF",
        Keyword:                   "bold #008000",
        Keyword.Pseudo:            "nobold",
        Keyword.Type:              "nobold #B00040",

        # Operator:                  "#666666",
        # Operator.Word:             "bold #AA22FF",

        Name.Builtin:              "#008000",
        Name.Function:             "#0000FF",
        Name.Class:                "bold #0000FF",
        # Name.Namespace:            "bold #0000FF",
        Name.Exception:            "bold #D2413A",
        Name.Variable:             "#19177C",
        Name.Constant:             "#880000",
        Name.Label:                "#A0A000",
        Name.Entity:               "bold #999999",
        Name.Attribute:            "#7D9029",
        Name.Tag:                  "bold #008000",
        Name.Decorator:            "#AA22FF",

        String:                    "#BA2121",
        String.Doc:                "italic",
        String.Interpol:           "bold #BB6688",
        String.Escape:             "bold #BB6622",
        String.Regex:              "#BB6688",
        # String.Symbol:             "#B8860B",
        String.Symbol:             "#19177C",
        String.Other:              "#008000",
        # Number:                    "#666666",

        Generic.Heading:           "bold #000080",
        Generic.Subheading:        "bold #800080",
        Generic.Deleted:           "#A00000",
        Generic.Inserted:          "#00A000",
        Generic.Error:             "#FF0000",
        Generic.Emph:              "italic",
        Generic.Strong:            "bold",
        Generic.Prompt:            "bold #000080",
        Generic.Output:            "#888",
        Generic.Traceback:         "#04D",

        Error:                     "border:#FF0000",
        # The following are the deviations from the default
        # need more operator information
        Operator:      "#AA22FF",
        Operator.Word: "bold #008000",

        Name.Namespace: "#000000",  # may be different in lab

        Number:         "#008800",
    }



import os
import shutil
import nbconvert
import argparse


TEMPLATES = {"style_jupyter.tplx", "classic.tplx", "classicm.tplx"}


def install():
    """Copies the templates into the necessary location to be
    globally accessible to nbconvert.
    """
    nbconvert_path = os.path.dirname(nbconvert.__file__)
    dst = os.path.abspath(os.path.join(nbconvert_path, "templates", "latex"))
    if not os.path.isdir(dst):
        raise OSError("Directory: %s not found." % dst)

    module_path = os.path.dirname(os.path.realpath(__file__))
    template_path = os.path.abspath(os.path.join(module_path, "templates"))
    found_templates = os.listdir(template_path)
    if TEMPLATES != set(found_templates):
        raise ValueError("Templates not found")

    for template in TEMPLATES:
        if template == 'style_jupyter_minted.tplx':
            continue
        src = os.path.join(template_path, template)
        shutil.copy(src, dst)

    print("Success")


if __name__ == "__main__":
    install()
